@@ -95,6 +95,9 @@ class SvnClientTest(SvnClientTestSetups):
         self.assertTrue(client.detect_presence())
         self.assertEqual(client.get_url(), self.readonly_url)
         #self.assertEqual(client.get_version(), self.readonly_version)
+        self.assertEqual(client.get_version("PREV"), "-r2")
+        self.assertEqual(client.get_version("2"), "-r2")
+        self.assertEqual(client.get_version("-r2"), "-r2")
 
     def test_get_type_name(self):
         from vcstools.svn import SvnClient
@@ -126,28 +129,26 @@ class SvnClientTest(SvnClientTestSetups):
 
         #self.assertEqual(client.get_version(), '-r*')
 
-    def test_checkout_specific_version_and_update(self):
+    def test_checkout_specific_version_and_update_short(self):
+        "using just a number as version"
         from vcstools.svn import SvnClient
         directory = tempfile.mkdtemp()
         subdir = "checkout_specific_version_test"
         self.directories[subdir] = directory
         local_path = os.path.join(directory, "ros")
         url = self.readonly_url
-        version = "-r3"
+        version = "3"
         client = SvnClient(local_path)
         self.assertFalse(client.path_exists())
         self.assertFalse(client.detect_presence())
-        self.assertFalse(client.detect_presence())
         self.assertTrue(client.checkout(url, version))
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
-        self.assertEqual(client.get_path(), local_path)
-        self.assertEqual(client.get_url(), url)
-        #self.assertEqual(client.get_version(), version)
+        self.assertEqual(client.get_version(), "-r3")
         
-        new_version = '-r2'
+        new_version = '2'
         self.assertTrue(client.update(new_version))
-
+        self.assertEqual(client.get_version(), "-r2")
 
 class SvnDiffStatClientTest(SvnClientTestSetups):
 
